@@ -182,6 +182,41 @@ def test_catalog_update_data_source_resource() -> None:
     ]
 
 
+def test_catalog_udpate_data_source_resource_with_extension() -> None:
+    repo = DirectoryRepo(location="")
+    catalog = Catalog(repo=repo)
+    catalog.get_all_data_sources()
+
+    updated_data_source = catalog.update_data_source_resource(
+        "s3://bwell-ingestion/preprocessed/burris_highmark_claims_medical/20210915_2645841001FLX.txt"
+    )
+
+    assert updated_data_source is not None
+    claims_resource = updated_data_source.resources[0]
+    assert claims_resource.name == "burris_highmark_claims_medical"
+    assert (
+        claims_resource.full_path
+        == "s3://bwell-ingestion/preprocessed/burris_highmark_claims_medical/20210915_2645841001FLX.txt"
+    )
+
+    updated_data_source = catalog.update_data_source_resource(
+        "s3://bwell-ingestion/preprocessed/burris_highmark_claims_medical/20210916_2645841001FLX.txt.gz"
+    )
+
+    assert updated_data_source is None
+
+    data_source = catalog.get_data_source(
+        "catalog/preprocessed/burris/highmark/claims_medical.json",
+        HelixEnvironment.PRODUCTION,
+    )
+    assert data_source is not None
+    claims_resource = data_source.resources[0]
+    assert (
+        claims_resource.full_path
+        == "s3://bwell-ingestion/preprocessed/burris_highmark_claims_medical/20210915_2645841001FLX.txt"
+    )
+
+
 def test_catalog_update_data_source_resource_returns_none() -> None:
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
@@ -232,8 +267,8 @@ def test_catalog_get_resource_unprocessed_directories() -> None:
     )
     assert len(paths_to_process) == 2
     assert paths_to_process == [
-        "data/raw/thedacare/betteru/2021-07-02",
-        "data/raw/thedacare/betteru/2021-07-05",
+        "data/raw/thedacare/betteru/2021-07-02/some-patient-file.csv",
+        "data/raw/thedacare/betteru/2021-07-05/some-patient-file.csv",
     ]
     catalog.update_resource_last_processed(
         "betteru", paths_to_process[0], data_source, HelixEnvironment.PRODUCTION
@@ -242,4 +277,23 @@ def test_catalog_get_resource_unprocessed_directories() -> None:
         "betteru", data_source, HelixEnvironment.PRODUCTION
     )
     assert len(paths_to_process) == 1
-    assert paths_to_process == ["data/raw/thedacare/betteru/2021-07-05"]
+    assert paths_to_process == [
+        "data/raw/thedacare/betteru/2021-07-05/some-patient-file.csv"
+    ]
+
+
+def test_catalog_get_resource_unprocessed_directories_segments() -> None:
+    repo = DirectoryRepo(location="")
+    catalog = Catalog(repo=repo)
+    data_source = catalog.get_data_source(
+        "catalog/events/mixpanel/events.json", HelixEnvironment.PRODUCTION
+    )
+    assert data_source is not None
+    paths_to_process = catalog.get_resource_unprocessed_directories(
+        "2095895", data_source, HelixEnvironment.PRODUCTION
+    )
+    assert len(paths_to_process) == 2
+    assert paths_to_process == [
+        "data/events/2095895/2021/10/02/some-patient-file.csv",
+        "data/events/2095895/2021/10/03/some-patient-file.csv",
+    ]
